@@ -61,50 +61,50 @@ FileViewBazaarPlugin::FileViewBazaarPlugin(QObject* parent, const QList<QVariant
     m_updateAction = new QAction(this);
     m_updateAction->setIcon(QIcon::fromTheme("go-down"));
     m_updateAction->setText(i18nc("@item:inmenu", "Bazaar Update"));
-    connect(m_updateAction, SIGNAL(triggered()),
-            this, SLOT(updateFiles()));
+    connect(m_updateAction, &QAction::triggered,
+            this, &FileViewBazaarPlugin::updateFiles);
 
     m_pullAction = new QAction(this);
     m_pullAction->setIcon(QIcon::fromTheme("go-bottom"));
     m_pullAction->setText(i18nc("@item:inmenu", "Bazaar Pull"));
-    connect(m_pullAction, SIGNAL(triggered()),
-            this, SLOT(pullFiles()));
+    connect(m_pullAction, &QAction::triggered,
+            this, &FileViewBazaarPlugin::pullFiles);
 
     m_pushAction = new QAction(this);
     m_pushAction->setIcon(QIcon::fromTheme("go-top"));
     m_pushAction->setText(i18nc("@item:inmenu", "Bazaar Push"));
-    connect(m_pushAction, SIGNAL(triggered()),
-            this, SLOT(pushFiles()));
+    connect(m_pushAction, &QAction::triggered,
+            this, &FileViewBazaarPlugin::pushFiles);
 
     m_showLocalChangesAction = new QAction(this);
     m_showLocalChangesAction->setIcon(QIcon::fromTheme("view-split-left-right"));
     m_showLocalChangesAction->setText(i18nc("@item:inmenu", "Show Local Bazaar Changes"));
-    connect(m_showLocalChangesAction, SIGNAL(triggered()),
-            this, SLOT(showLocalChanges()));
+    connect(m_showLocalChangesAction, &QAction::triggered,
+            this, &FileViewBazaarPlugin::showLocalChanges);
 
     m_commitAction = new QAction(this);
     m_commitAction->setIcon(QIcon::fromTheme("svn-commit"));
     m_commitAction->setText(i18nc("@item:inmenu", "Bazaar Commit..."));
-    connect(m_commitAction, SIGNAL(triggered()),
-            this, SLOT(commitFiles()));
+    connect(m_commitAction, &QAction::triggered,
+            this, &FileViewBazaarPlugin::commitFiles);
 
     m_addAction = new QAction(this);
     m_addAction->setIcon(QIcon::fromTheme("list-add"));
     m_addAction->setText(i18nc("@item:inmenu", "Bazaar Add..."));
-    connect(m_addAction, SIGNAL(triggered()),
-            this, SLOT(addFiles()));
+    connect(m_addAction, &QAction::triggered,
+            this, &FileViewBazaarPlugin::addFiles);
 
     m_removeAction = new QAction(this);
     m_removeAction->setIcon(QIcon::fromTheme("list-remove"));
     m_removeAction->setText(i18nc("@item:inmenu", "Bazaar Delete"));
-    connect(m_removeAction, SIGNAL(triggered()),
-            this, SLOT(removeFiles()));
+    connect(m_removeAction, &QAction::triggered,
+            this, &FileViewBazaarPlugin::removeFiles);
 
     m_logAction = new QAction(this);
     m_logAction->setIcon(QIcon::fromTheme("format-list-ordered"));
     m_logAction->setText(i18nc("@item:inmenu", "Bazaar Log"));
-    connect(m_logAction, SIGNAL(triggered()),
-            this, SLOT(log()));
+    connect(m_logAction, &QAction::triggered,
+            this, &FileViewBazaarPlugin::log);
 
     connect(&m_process, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
             this, &FileViewBazaarPlugin::slotOperationCompleted);
@@ -128,7 +128,7 @@ bool FileViewBazaarPlugin::beginRetrieval(const QString& directory)
     QString baseDir;
     QProcess process1;
     process1.setWorkingDirectory(directory);
-    process1.start(QLatin1String("bzr root"));
+    process1.start(QLatin1String("bzr"), {"root"});
     while (process1.waitForReadyRead()) {
         char buffer[512];
         while (process1.readLine(buffer, sizeof(buffer)) > 0)  {
@@ -152,7 +152,7 @@ bool FileViewBazaarPlugin::beginRetrieval(const QString& directory)
 
     QProcess process2;
     process2.setWorkingDirectory(directory);
-    process2.start(QLatin1String("bzr ignored"));
+    process2.start(QLatin1String("bzr"), {"ignored"});
     while (process2.waitForReadyRead()) {
         char buffer[512];
         while (process2.readLine(buffer, sizeof(buffer)) > 0)  {
@@ -282,7 +282,7 @@ QList<QAction*> FileViewBazaarPlugin::outOfVersionControlActions(const KFileItem
 QList<QAction*> FileViewBazaarPlugin::contextMenuFilesActions(const KFileItemList& items) const
 {
     Q_ASSERT(!items.isEmpty());
-    foreach (const KFileItem& item, items) {
+    for (const KFileItem& item : items) {
         m_contextItems.append(item);
     }
     m_contextDir.clear();
@@ -294,7 +294,7 @@ QList<QAction*> FileViewBazaarPlugin::contextMenuFilesActions(const KFileItemLis
         const int itemsCount = items.count();
         int versionedCount = 0;
         int editingCount = 0;
-        foreach (const KFileItem& item, items) {
+        for (const KFileItem& item : items) {
             const ItemVersion state = itemVersion(item);
             if (state != UnversionedVersion) {
                 ++versionedCount;
@@ -436,10 +436,10 @@ void FileViewBazaarPlugin::slotOperationCompleted(int exitCode, QProcess::ExitSt
     m_pendingOperation = false;
 
     if ((exitStatus != QProcess::NormalExit) || (exitCode != 0)) {
-        emit errorMessage(m_errorMsg);
+        Q_EMIT errorMessage(m_errorMsg);
     } else if (m_contextItems.isEmpty()) {
-        emit operationCompletedMessage(m_operationCompletedMsg);
-        emit itemVersionsChanged();
+        Q_EMIT operationCompletedMessage(m_operationCompletedMsg);
+        Q_EMIT itemVersionsChanged();
     } else {
         startBazaarCommandProcess();
     }
@@ -451,7 +451,7 @@ void FileViewBazaarPlugin::slotOperationError()
     m_contextItems.clear();
     m_pendingOperation = false;
 
-    emit errorMessage(m_errorMsg);
+    Q_EMIT errorMessage(m_errorMsg);
 }
 
 void FileViewBazaarPlugin::execBazaarCommand(const QString& command,
@@ -460,10 +460,10 @@ void FileViewBazaarPlugin::execBazaarCommand(const QString& command,
                                        const QString& errorMsg,
                                        const QString& operationCompletedMsg)
 {
-    emit infoMessage(infoMsg);
+    Q_EMIT infoMessage(infoMsg);
 
     QProcess process;
-    process.start(QLatin1String("bzr plugins"));
+    process.start(QLatin1String("bzr"), {"plugins"});
     bool foundQbzr = false;
     while (process.waitForReadyRead()) {
         char buffer[512];
@@ -477,7 +477,7 @@ void FileViewBazaarPlugin::execBazaarCommand(const QString& command,
     }
 
     if (!foundQbzr) {
-        emit infoMessage("Please Install QBzr");
+        Q_EMIT infoMessage("Please Install QBzr");
         return;
     }
     
