@@ -28,7 +28,6 @@
 #include "pulldialog.h"
 
 #include <KLocalizedString>
-#include <KRun>
 #include <KShell>
 #include <KPluginFactory>
 
@@ -58,53 +57,53 @@ FileViewGitPlugin::FileViewGitPlugin(QObject* parent, const QList<QVariant>& arg
     m_revertAction = new QAction(this);
     m_revertAction->setIcon(QIcon::fromTheme("document-revert"));
     m_revertAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Revert"));
-    connect(m_revertAction, SIGNAL(triggered()),
-            this, SLOT(revertFiles()));
+    connect(m_revertAction, &QAction::triggered,
+            this, &FileViewGitPlugin::revertFiles);
 
     m_addAction = new QAction(this);
     m_addAction->setIcon(QIcon::fromTheme("list-add"));
     m_addAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Add"));
-    connect(m_addAction, SIGNAL(triggered()),
-            this, SLOT(addFiles()));
+    connect(m_addAction, &QAction::triggered,
+            this, &FileViewGitPlugin::addFiles);
 
     m_showLocalChangesAction = new QAction(this);
     m_showLocalChangesAction->setIcon(QIcon::fromTheme("view-split-left-right"));
     m_showLocalChangesAction->setText(xi18nd("@item:inmenu", "Show Local <application>Git</application> Changes"));
-    connect(m_showLocalChangesAction, SIGNAL(triggered()),
-            this, SLOT(showLocalChanges()));
+    connect(m_showLocalChangesAction, &QAction::triggered,
+            this, &FileViewGitPlugin::showLocalChanges);
 
     m_removeAction = new QAction(this);
     m_removeAction->setIcon(QIcon::fromTheme("list-remove"));
     m_removeAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Remove"));
-    connect(m_removeAction, SIGNAL(triggered()),
-            this, SLOT(removeFiles()));
+    connect(m_removeAction, &QAction::triggered,
+            this, &FileViewGitPlugin::removeFiles);
 
     m_checkoutAction = new QAction(this);
 //     m_checkoutAction->setIcon(QIcon::fromTheme("svn_switch")); does not exist in normal kde SC
     m_checkoutAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Checkout..."));
-    connect(m_checkoutAction, SIGNAL(triggered()),
-            this, SLOT(checkout()));
+    connect(m_checkoutAction, &QAction::triggered,
+            this, &FileViewGitPlugin::checkout);
 
     m_commitAction = new QAction(this);
     m_commitAction->setIcon(QIcon::fromTheme("svn-commit"));
     m_commitAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Commit..."));
-    connect(m_commitAction, SIGNAL(triggered()),
-            this, SLOT(commit()));
+    connect(m_commitAction, &QAction::triggered,
+            this, &FileViewGitPlugin::commit);
 
     m_tagAction = new QAction(this);
 //     m_tagAction->setIcon(QIcon::fromTheme("svn-commit"));
     m_tagAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Create Tag..."));
-    connect(m_tagAction, SIGNAL(triggered()),
-            this, SLOT(createTag()));
+    connect(m_tagAction, &QAction::triggered,
+            this, &FileViewGitPlugin::createTag);
     m_pushAction = new QAction(this);
 //     m_pushAction->setIcon(QIcon::fromTheme("svn-commit"));
     m_pushAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Push..."));
-    connect(m_pushAction, SIGNAL(triggered()),
-            this, SLOT(push()));
+    connect(m_pushAction, &QAction::triggered,
+            this, &FileViewGitPlugin::push);
     m_pullAction = new QAction(this);
     m_pullAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Pull..."));
-    connect(m_pullAction, SIGNAL(triggered()),
-            this, SLOT(pull()));
+    connect(m_pullAction, &QAction::triggered,
+            this, &FileViewGitPlugin::pull);
     m_mergeAction = new QAction(this);
     m_mergeAction->setIcon(QIcon::fromTheme("merge"));
     m_mergeAction->setText(xi18nd("@action:inmenu", "<application>Git</application> Merge..."));
@@ -165,7 +164,7 @@ bool FileViewGitPlugin::beginRetrieval(const QString& directory)
     // ----- find path below git base dir -----
     QProcess process;
     process.setWorkingDirectory(directory);
-    process.start(QLatin1String("git rev-parse --show-prefix"));
+    process.start("git", {"rev-parse", "--show-prefix"});
     QString dirBelowBaseDir = "";
     while (process.waitForReadyRead()) {
         char buffer[512];
@@ -177,7 +176,7 @@ bool FileViewGitPlugin::beginRetrieval(const QString& directory)
     m_versionInfoHash.clear();
 
     // ----- find files with special status -----
-    process.start(QLatin1String("git status --porcelain -z -u --ignored"));
+    process.start("git", {"--no-optional-locks", "status", "--porcelain", "-z", "-u", "--ignored"});
     while (process.waitForReadyRead()) {
         char buffer[1024];
         while (readUntilZeroChar(&process, buffer, sizeof(buffer)) > 0 ) {
@@ -308,7 +307,7 @@ QList<QAction*> FileViewGitPlugin::contextMenuFilesActions(const KFileItemList&
     if (!m_pendingOperation){
         m_contextDir = QFileInfo(items.first().localPath()).canonicalPath();
         m_contextItems.clear();
-        foreach(const KFileItem& item, items){
+        for (const KFileItem& item : items){
             m_contextItems.append(item);
         }
 
@@ -316,7 +315,7 @@ QList<QAction*> FileViewGitPlugin::contextMenuFilesActions(const KFileItemList&
         int versionedCount = 0;
         int addableCount = 0;
         int revertCount = 0;
-        foreach(const KFileItem& item, items){
+        for (const KFileItem& item : items){
             const ItemVersion state = itemVersion(item);
             if (state != UnversionedVersion && state != RemovedVersion &&
                 state != IgnoredVersion) {
@@ -438,7 +437,7 @@ void FileViewGitPlugin::showLocalChanges()
 {
     Q_ASSERT(!m_contextDir.isEmpty());
 
-    KRun::runCommand(QLatin1String("git difftool --dir-diff ."), nullptr, m_contextDir);
+    runCommand(QLatin1String("git difftool --dir-diff ."));
 }
 
 void FileViewGitPlugin::showDiff(const QUrl &link)
@@ -446,7 +445,7 @@ void FileViewGitPlugin::showDiff(const QUrl &link)
     if (link.scheme() != QLatin1String("rev")) {
         return;
     }
-    KRun::runCommand(QStringLiteral("git difftool --dir-diff %1^ %1").arg(link.path()), nullptr, m_contextDir);
+    runCommand(QStringLiteral("git difftool --dir-diff %1^ %1").arg(link.path()));
 }
 
 void FileViewGitPlugin::log()
@@ -473,7 +472,7 @@ void FileViewGitPlugin::log()
     );
 
     if (!process.waitForFinished() || process.exitCode() != 0) {
-        emit errorMessage(xi18nd("@info:status", "<application>Git</application> Log failed."));
+        Q_EMIT errorMessage(xi18nd("@info:status", "<application>Git</application> Log failed."));
         return;
     }
 
@@ -522,7 +521,7 @@ void FileViewGitPlugin::merge()
 {
     Q_ASSERT(!m_contextDir.isEmpty());
 
-    KRun::runCommand(QStringLiteral("git mergetool"), nullptr, m_contextDir);
+    runCommand(QStringLiteral("git mergetool"));
 }
 
 void FileViewGitPlugin::checkout()
@@ -571,12 +570,12 @@ void FileViewGitPlugin::checkout()
         }
         if (process.exitCode() == 0 && process.exitStatus() == QProcess::NormalExit) {
             if (!completedMessage.isEmpty()) {
-                emit operationCompletedMessage(completedMessage);
-                emit itemVersionsChanged();
+                Q_EMIT operationCompletedMessage(completedMessage);
+                Q_EMIT itemVersionsChanged();
             }
         }
         else {
-            emit errorMessage(xi18nd("@info:status", "<application>Git</application> Checkout failed."
+            Q_EMIT errorMessage(xi18nd("@info:status", "<application>Git</application> Checkout failed."
             " Maybe your working directory is dirty."));
         }
     }
@@ -592,7 +591,13 @@ void FileViewGitPlugin::commit()
         tmpCommitMessageFile.close();
         QProcess process;
         process.setWorkingDirectory(m_contextDir);
-        process.start(QString("git commit") + (dialog.amend() ? " --amend" : "")+ " -F " + tmpCommitMessageFile.fileName());
+        QStringList args = {"commit"};
+        if (dialog.amend()) {
+            args << "--amend";
+        }
+        args << "-F";
+        args << tmpCommitMessageFile.fileName();
+        process.start("git", args);
         QString completedMessage;
         while (process.waitForReadyRead()){
             char buffer[512];
@@ -604,8 +609,8 @@ void FileViewGitPlugin::commit()
             }
         }
         if (!completedMessage.isEmpty()) {
-            emit operationCompletedMessage(completedMessage);
-            emit itemVersionsChanged();
+            Q_EMIT operationCompletedMessage(completedMessage);
+            Q_EMIT itemVersionsChanged();
         }
     }
 }
@@ -621,8 +626,7 @@ void FileViewGitPlugin::createTag()
         QProcess process;
         process.setWorkingDirectory(m_contextDir);
         process.setReadChannel(QProcess::StandardError);
-        process.start(QString("git tag -a -F %1 %2 %3").arg(tempTagMessageFile.fileName()).
-            arg(dialog.tagName()).arg(dialog.baseBranch()));
+        process.start("git", {"tag", "-a", "-F", tempTagMessageFile.fileName(), dialog.tagName(), dialog.baseBranch()});
         QString completedMessage;
         bool gotTagAlreadyExistsMessage = false;
         while (process.waitForReadyRead()) {
@@ -636,10 +640,10 @@ void FileViewGitPlugin::createTag()
         }
         if (process.exitCode() == 0 && process.exitStatus() == QProcess::NormalExit) {
             completedMessage = xi18nd("@info:status","Successfully created tag '%1'", dialog.tagName());
-            emit operationCompletedMessage(completedMessage);
+            Q_EMIT operationCompletedMessage(completedMessage);
         } else {
             //I don't know any other error, but in case one occurs, the user doesn't get FALSE error messages
-            emit errorMessage(gotTagAlreadyExistsMessage ?
+            Q_EMIT errorMessage(gotTagAlreadyExistsMessage ?
                 xi18nd("@info:status", "<application>Git</application> tag creation failed."
                                       " A tag with the name '%1' already exists.", dialog.tagName()) :
                 xi18nd("@info:status", "<application>Git</application> tag creation failed.")
@@ -658,14 +662,19 @@ void FileViewGitPlugin::push()
                         dialog.localBranch(), dialog.destination(), dialog.remoteBranch());
         m_operationCompletedMsg = xi18nd("@info:status", "Pushed branch %1 to %2:%3.",
                         dialog.localBranch(), dialog.destination(), dialog.remoteBranch());
-        emit infoMessage(xi18nd("@info:status", "Pushing branch %1 to %2:%3...",
+        Q_EMIT infoMessage(xi18nd("@info:status", "Pushing branch %1 to %2:%3...",
                  dialog.localBranch(), dialog.destination(), dialog.remoteBranch()));
 
         m_command = "push";
         m_pendingOperation = true;
-        m_process.start(QString("git push%4 %1 %2:%3").arg(dialog.destination()).
-            arg(dialog.localBranch()).arg(dialog.remoteBranch()).
-            arg(dialog.force() ? QLatin1String(" --force") : QLatin1String("")));
+        QStringList args;
+        args << "push";
+        if (dialog.force()) {
+            args << "--force";
+        }
+        args << dialog.destination();
+        args << QStringLiteral("%1:%2").arg(dialog.localBranch(), dialog.remoteBranch());
+        m_process.start("git", args);
     }
 }
 
@@ -679,12 +688,12 @@ void FileViewGitPlugin::pull()
                         dialog.remoteBranch(), dialog.source());
         m_operationCompletedMsg = xi18nd("@info:status", "Pulled branch %1 from %2 successfully.",
                         dialog.remoteBranch(), dialog.source());
-        emit infoMessage(xi18nd("@info:status", "Pulling branch %1 from %2...", dialog.remoteBranch(),
+        Q_EMIT infoMessage(xi18nd("@info:status", "Pulling branch %1 from %2...", dialog.remoteBranch(),
                     dialog.source()));
 
         m_command = "pull";
         m_pendingOperation = true;
-        m_process.start(QString("git pull %1 %2").arg(dialog.source()).arg(dialog.remoteBranch()));
+        m_process.start("git", {"pull", dialog.source(), dialog.remoteBranch()});
     }
 }
 
@@ -703,10 +712,10 @@ void FileViewGitPlugin::slotOperationCompleted(int exitCode, QProcess::ExitStatu
     }
 
     if ((exitStatus != QProcess::NormalExit) || (exitCode != 0)) {
-        emit errorMessage(message.isNull() ? m_errorMsg : message);
+        Q_EMIT errorMessage(message.isNull() ? m_errorMsg : message);
     } else if (m_contextItems.isEmpty()) {
-        emit operationCompletedMessage(message.isNull() ? m_operationCompletedMsg : message);
-        emit itemVersionsChanged();
+        Q_EMIT operationCompletedMessage(message.isNull() ? m_operationCompletedMsg : message);
+        Q_EMIT itemVersionsChanged();
     } else {
         startGitCommandProcess();
     }
@@ -718,7 +727,7 @@ void FileViewGitPlugin::slotOperationError()
     m_contextItems.clear();
     m_pendingOperation = false;
 
-    emit errorMessage(m_errorMsg);
+    Q_EMIT errorMessage(m_errorMsg);
 }
 
 QString FileViewGitPlugin::parsePushOutput()
@@ -747,7 +756,7 @@ QString FileViewGitPlugin::parsePullOutput()
             return xi18nd("@info:status", "Branch is already up-to-date.");
         }
         if (line.contains("CONFLICT")) {
-            emit itemVersionsChanged();
+            Q_EMIT itemVersionsChanged();
             return xi18nd("@info:status", "Merge conflicts occurred. Fix them and commit the result.");
         }
     }
@@ -760,7 +769,7 @@ void FileViewGitPlugin::execGitCommand(const QString& gitCommand,
                                        const QString& errorMsg,
                                        const QString& operationCompletedMsg)
 {
-    emit infoMessage(infoMsg);
+    Q_EMIT infoMessage(infoMsg);
 
     m_command = gitCommand;
     m_arguments = arguments;
