@@ -44,10 +44,10 @@ class HgBundleDialog : public DialogBase
 public:
     explicit HgBundleDialog(QWidget *parent=0);
 
-public slots:
+public Q_SLOTS:
     void done(int r) override;
 
-private slots:
+private Q_SLOTS:
     void saveGeometry();
 
     /**
