@@ -158,8 +158,8 @@ HgCommitDialog::HgCommitDialog(QWidget *parent):
 
     connect(m_statusList, &HgStatusList::itemSelectionChanged,
         this, &HgCommitDialog::slotItemSelectionChanged);
-    connect(m_commitMessage, SIGNAL(textChanged(KTextEditor::Document*)),
-         this, SLOT(slotMessageChanged()));
+    connect(m_commitMessage, &KTextEditor::Document::textChanged,
+         this, &HgCommitDialog::slotMessageChanged);
     connect(this, SIGNAL(finished(int)), this, SLOT(saveGeometry()));
 }
 
@@ -324,8 +324,8 @@ NewBranchDialog::NewBranchDialog(QWidget *parent):
 
     connect(m_branchNameInput, &QLineEdit::textChanged,
             this, &NewBranchDialog::slotTextChanged);
-    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
 void NewBranchDialog::slotTextChanged(const QString &text)
@@ -366,8 +366,8 @@ void HgCommitDialog::createCopyMessageMenu()
     QString output;
     hgw->executeCommand(QLatin1String("log"), args, output);
 
-    QStringList messages = output.split('\n', QString::SkipEmptyParts);
-    foreach (QString msg, messages) {
+    const QStringList messages = output.split('\n', QString::SkipEmptyParts);
+    for (const QString &msg : messages) {
         QAction *action = m_copyMessageMenu->addAction(msg.left(40)); // max 40 characters
         action->setData(msg); // entire description into action data
         actionGroup->addAction(action);
