@@ -40,10 +40,10 @@ class HgExportDialog : public DialogBase
 public:
     explicit HgExportDialog(QWidget *parent=0);
 
-public slots:
+public Q_SLOTS:
     void done(int r) override;
 
-private slots:
+private Q_SLOTS:
     void saveGeometry();
 
 private:
