@@ -103,169 +103,169 @@ FileViewHgPlugin::FileViewHgPlugin(QObject *parent, const QList<QVariant> &args)
     m_addAction->setIcon(QIcon::fromTheme("list-add"));
     m_addAction->setText(xi18nc("@action:inmenu",
                                "<application>Hg</application> Add"));
-    connect(m_addAction, SIGNAL(triggered()),
-            this, SLOT(addFiles()));
+    connect(m_addAction, &QAction::triggered,
+            this, &FileViewHgPlugin::addFiles);
 
     m_removeAction = new QAction(this);
     m_removeAction->setIcon(QIcon::fromTheme("list-remove"));
     m_removeAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Remove"));
-    connect(m_removeAction, SIGNAL(triggered()),
-            this, SLOT(removeFiles()));
+    connect(m_removeAction, &QAction::triggered,
+            this, &FileViewHgPlugin::removeFiles);
 
     m_renameAction = new QAction(this);
     m_renameAction->setIcon(QIcon::fromTheme("list-rename"));
     m_renameAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Rename"));
-    connect(m_renameAction, SIGNAL(triggered()),
-            this, SLOT(renameFile()));
+    connect(m_renameAction, &QAction::triggered,
+            this, &FileViewHgPlugin::renameFile);
 
     m_commitAction = new QAction(this);
     m_commitAction->setIcon(QIcon::fromTheme("svn-commit"));
     m_commitAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Commit"));
-    connect(m_commitAction, SIGNAL(triggered()),
-            this, SLOT(commit()));
+    connect(m_commitAction, &QAction::triggered,
+            this, &FileViewHgPlugin::commit);
 
     m_tagAction = new QAction(this);
     m_tagAction->setIcon(QIcon::fromTheme("svn-tag"));
     m_tagAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Tag"));
-    connect(m_tagAction, SIGNAL(triggered()),
-            this, SLOT(tag()));
+    connect(m_tagAction, &QAction::triggered,
+            this, &FileViewHgPlugin::tag);
 
     m_branchAction = new QAction(this);
     m_branchAction->setIcon(QIcon::fromTheme("svn-branch"));
     m_branchAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Branch"));
-    connect(m_branchAction, SIGNAL(triggered()),
-            this, SLOT(branch()));
+    connect(m_branchAction, &QAction::triggered,
+            this, &FileViewHgPlugin::branch);
 
     m_cloneAction = new QAction(this);
     m_cloneAction->setIcon(QIcon::fromTheme("hg-clone"));
     m_cloneAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Clone"));
-    connect(m_cloneAction, SIGNAL(triggered()),
-            this, SLOT(clone()));
+    connect(m_cloneAction, &QAction::triggered,
+            this, &FileViewHgPlugin::clone);
 
     m_createAction = new QAction(this);
     m_createAction->setIcon(QIcon::fromTheme("hg-create"));
     m_createAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Init"));
-    connect(m_createAction, SIGNAL(triggered()),
-            this, SLOT(create()));
+    connect(m_createAction, &QAction::triggered,
+            this, &FileViewHgPlugin::create);
 
     m_updateAction = new QAction(this);
     m_updateAction->setIcon(QIcon::fromTheme("svn-update"));
     m_updateAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Update"));
-    connect(m_updateAction, SIGNAL(triggered()),
-            this, SLOT(update()));
+    connect(m_updateAction, &QAction::triggered,
+            this, &FileViewHgPlugin::update);
 
     m_globalConfigAction = new QAction(this);
     m_globalConfigAction->setIcon(QIcon::fromTheme("hg-config"));
     m_globalConfigAction->setText(xi18nc("@action:inmenu",
                           "<application>Hg</application> Global Config"));
-    connect(m_globalConfigAction, SIGNAL(triggered()),
-            this, SLOT(global_config()));
+    connect(m_globalConfigAction, &QAction::triggered,
+            this, &FileViewHgPlugin::global_config);
 
     m_repoConfigAction = new QAction(this);
     m_repoConfigAction->setIcon(QIcon::fromTheme("hg-config"));
     m_repoConfigAction->setText(xi18nc("@action:inmenu",
                       "<application>Hg</application> Repository Config"));
-    connect(m_repoConfigAction, SIGNAL(triggered()),
-            this, SLOT(repo_config()));
+    connect(m_repoConfigAction, &QAction::triggered,
+            this, &FileViewHgPlugin::repo_config);
 
     m_pushAction = new QAction(this);
     m_pushAction->setIcon(QIcon::fromTheme("git-push"));
     m_pushAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Push"));
-    connect(m_pushAction, SIGNAL(triggered()),
-            this, SLOT(push()));
+    connect(m_pushAction, &QAction::triggered,
+            this, &FileViewHgPlugin::push);
 
     m_pullAction = new QAction(this);
     m_pullAction->setIcon(QIcon::fromTheme("git-pull"));
     m_pullAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Pull"));
-    connect(m_pullAction, SIGNAL(triggered()),
-            this, SLOT(pull()));
+    connect(m_pullAction, &QAction::triggered,
+            this, &FileViewHgPlugin::pull);
 
     m_revertAction = new QAction(this);
     m_revertAction->setIcon(QIcon::fromTheme("hg-revert"));
     m_revertAction->setText(xi18nc("@action:inmenu",
                                   "<application>Hg</application> Revert"));
-    connect(m_revertAction, SIGNAL(triggered()),
-            this, SLOT(revert()));
+    connect(m_revertAction, &QAction::triggered,
+            this, &FileViewHgPlugin::revert);
 
     m_revertAllAction = new QAction(this);
     m_revertAllAction->setIcon(QIcon::fromTheme("hg-revert"));
     m_revertAllAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Revert All"));
-    connect(m_revertAllAction, SIGNAL(triggered()),
-            this, SLOT(revertAll()));
+    connect(m_revertAllAction, &QAction::triggered,
+            this, &FileViewHgPlugin::revertAll);
 
     m_rollbackAction = new QAction(this);
     m_rollbackAction->setIcon(QIcon::fromTheme("hg-rollback"));
     m_rollbackAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Rollback"));
-    connect(m_rollbackAction, SIGNAL(triggered()),
-            this, SLOT(rollback()));
+    connect(m_rollbackAction, &QAction::triggered,
+            this, &FileViewHgPlugin::rollback);
 
     m_mergeAction = new QAction(this);
     m_mergeAction->setIcon(QIcon::fromTheme("hg-merge"));
     m_mergeAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Merge"));
-    connect(m_mergeAction, SIGNAL(triggered()),
-            this, SLOT(merge()));
+    connect(m_mergeAction, &QAction::triggered,
+            this, &FileViewHgPlugin::merge);
 
     m_bundleAction = new QAction(this);
     m_bundleAction->setIcon(QIcon::fromTheme("hg-bundle"));
     m_bundleAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Bundle"));
-    connect(m_bundleAction, SIGNAL(triggered()),
-            this, SLOT(bundle()));
+    connect(m_bundleAction, &QAction::triggered,
+            this, &FileViewHgPlugin::bundle);
 
     m_exportAction = new QAction(this);
     m_exportAction->setIcon(QIcon::fromTheme("hg-export"));
     m_exportAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Export"));
-    connect(m_exportAction, SIGNAL(triggered()),
-            this, SLOT(exportChangesets()));
+    connect(m_exportAction, &QAction::triggered,
+            this, &FileViewHgPlugin::exportChangesets);
 
     m_importAction = new QAction(this);
     m_importAction->setIcon(QIcon::fromTheme("hg-import"));
     m_importAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Import"));
-    connect(m_importAction, SIGNAL(triggered()),
-            this, SLOT(importChangesets()));
+    connect(m_importAction, &QAction::triggered,
+            this, &FileViewHgPlugin::importChangesets);
 
     m_unbundleAction = new QAction(this);
     m_unbundleAction->setIcon(QIcon::fromTheme("hg-unbundle"));
     m_unbundleAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Unbundle"));
-    connect(m_unbundleAction, SIGNAL(triggered()),
-            this, SLOT(unbundle()));
+    connect(m_unbundleAction, &QAction::triggered,
+            this, &FileViewHgPlugin::unbundle);
 
     m_serveAction = new QAction(this);
     m_serveAction->setIcon(QIcon::fromTheme("hg-serve"));
     m_serveAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Serve"));
-    connect(m_serveAction, SIGNAL(triggered()),
-            this, SLOT(serve()));
+    connect(m_serveAction, &QAction::triggered,
+            this, &FileViewHgPlugin::serve);
 
     m_backoutAction = new QAction(this);
     m_backoutAction->setIcon(QIcon::fromTheme("hg-backout"));
     m_backoutAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Backout"));
-    connect(m_backoutAction, SIGNAL(triggered()),
-            this, SLOT(backout()));
+    connect(m_backoutAction, &QAction::triggered,
+            this, &FileViewHgPlugin::backout);
 
     m_diffAction = new QAction(this);
     m_diffAction->setIcon(QIcon::fromTheme("hg-diff"));
     m_diffAction->setText(xi18nc("@action:inmenu",
                                  "<application>Hg</application> Diff"));
-    connect(m_diffAction, SIGNAL(triggered()),
-            this, SLOT(diff()));
+    connect(m_diffAction, &QAction::triggered,
+            this, &FileViewHgPlugin::diff);
 
     /* Submenu to make the main menu less cluttered */
     m_mainContextMenu = new QMenu;
@@ -361,12 +361,9 @@ KVersionControlPlugin::ItemVersion FileViewHgPlugin::itemVersion(const KFileItem
         // will disable the context menu there. Will enable recursive
         // add however.
         QDir dir(item.localPath());
-        QStringList filesInside = dir.entryList();
-        foreach (const QString &fileName, filesInside) {
-            if (fileName == "." || fileName == ".." ) {
-                continue;
-            }
-            QUrl tempUrl(dir.absoluteFilePath(fileName));
+        const QStringList filesInside = dir.entryList(QDir::AllEntries | QDir::NoDotAndDotDot);
+        for (const QString &fileName : filesInside) {
+            const QUrl tempUrl(dir.absoluteFilePath(fileName));
             KFileItem tempFileItem(tempUrl);
             if (itemVersion(tempFileItem) == NormalVersion) {
                return NormalVersion;
@@ -419,7 +416,7 @@ QList<QAction*> FileViewHgPlugin::itemContextMenu(const KFileItemList &items) co
     m_hgWrapper->setCurrentDir(m_currentDir);
     if (!m_hgWrapper->isBusy()) {
         m_contextItems.clear();
-        foreach (const KFileItem &item, items) {
+        for (const KFileItem &item : items) {
             m_contextItems.append(item);
         }
 
@@ -427,7 +424,7 @@ QList<QAction*> FileViewHgPlugin::itemContextMenu(const KFileItemList &items) co
         int versionedCount = 0;
         int addableCount = 0;
         int revertableCount = 0;
-        foreach (const KFileItem &item, items) {
+        for (const KFileItem &item : items) {
             const ItemVersion state = itemVersion(item);
             if (state != UnversionedVersion && state != RemovedVersion) {
                 ++versionedCount;
@@ -495,9 +492,9 @@ void FileViewHgPlugin::addFiles()
     m_operationCompletedMsg = xi18nc("@info:status",
          "Added files to <application>Hg</application> repository.");
 
-    emit infoMessage(infoMsg);
+    Q_EMIT infoMessage(infoMsg);
     m_hgWrapper->addFiles(m_contextItems);
-    emit itemVersionsChanged();
+    Q_EMIT itemVersionsChanged();
 }
 
 void FileViewHgPlugin::removeFiles()
@@ -518,7 +515,7 @@ void FileViewHgPlugin::removeFiles()
     m_operationCompletedMsg = xi18nc("@info:status",
          "Removed files from <application>Hg</application> repository.");
 
-    emit infoMessage(infoMsg);
+    Q_EMIT infoMessage(infoMsg);
     m_hgWrapper->removeFiles(m_contextItems);
 }
 
@@ -531,7 +528,7 @@ void FileViewHgPlugin::renameFile()
         "Renaming of file in <application>Hg</application> repository failed.");
     m_operationCompletedMsg = xi18nc("@info:status",
         "Renamed file in <application>Hg</application> repository successfully.");
-    emit infoMessage(xi18nc("@info:status",
+    Q_EMIT infoMessage(xi18nc("@info:status",
         "Renaming file in <application>Hg</application> repository."));
 
     HgRenameDialog dialog(m_contextItems.first());
@@ -551,12 +548,12 @@ void FileViewHgPlugin::commit()
             "Commit to <application>Hg</application> repository failed.");
     m_operationCompletedMsg = xi18nc("@info:status",
             "Committed to <application>Hg</application> repository.");
-    emit infoMessage(xi18nc("@info:status",
+    Q_EMIT infoMessage(xi18nc("@info:status",
             "Commit <application>Hg</application> repository."));
 
     HgCommitDialog dialog;
     if (dialog.exec() == QDialog::Accepted) {
-        emit itemVersionsChanged();
+        Q_EMIT itemVersionsChanged();
     };
 }
 
@@ -566,7 +563,7 @@ void FileViewHgPlugin::tag()
            "Tag operation in <application>Hg</application> repository failed.");
     m_operationCompletedMsg = xi18nc("@info:status",
            "Tagging operation in <application>Hg</application> repository is successful.");
-    emit infoMessage(xi18nc("@info:status",
+    Q_EMIT infoMessage(xi18nc("@info:status",
            "Tagging operation in <application>Hg</application> repository."));
 
     HgTagDialog dialog;
@@ -579,7 +576,7 @@ void FileViewHgPlugin::update()
            "Update of <application>Hg</application> working directory failed.");
     m_operationCompletedMsg = xi18nc("@info:status",
            "Update of <application>Hg</application> working directory is successful.");
-    emit infoMessage(xi18nc("@info:status",
+    Q_EMIT infoMessage(xi18nc("@info:status",
            "Updating <application>Hg</application> working directory."));
 
     HgUpdateDialog dialog;
@@ -592,7 +589,7 @@ void FileViewHgPlugin::branch()
            "Branch operation on <application>Hg</application> repository failed.");
     m_operationCompletedMsg = xi18nc("@info:status",
            "Branch operation on <application>Hg</application> repository completed successfully.");
-    emit infoMessage(xi18nc("@info:status",
+    Q_EMIT infoMessage(xi18nc("@info:status",
            "Branch operation on <application>Hg</application> repository."));
 
     HgBranchDialog dialog;
@@ -703,7 +700,7 @@ void FileViewHgPlugin::revert()
     m_operationCompletedMsg = xi18nc("@info:status",
          "Reverting files in <application>Hg</application> repository completed successfully.");
 
-    emit infoMessage(infoMsg);
+    Q_EMIT infoMessage(infoMsg);
     m_hgWrapper->revert(m_contextItems);
 }
 
@@ -723,7 +720,7 @@ void FileViewHgPlugin::revertAll()
     m_operationCompletedMsg = xi18nc("@info:status",
          "Reverting files in <application>Hg</application> repository completed successfully.");
 
-    emit infoMessage(infoMsg);
+    Q_EMIT infoMessage(infoMsg);
     m_hgWrapper->revertAll();
 }
 
@@ -736,7 +733,7 @@ void FileViewHgPlugin::diff()
     m_operationCompletedMsg = xi18nc("@info:status",
          "Generated <application>Hg</application> diff successfully.");
 
-    emit infoMessage(infoMsg);
+    Q_EMIT infoMessage(infoMsg);
 
     QStringList args;
     args << QLatin1String("--config");
@@ -801,28 +798,28 @@ void FileViewHgPlugin::rollback()
     m_operationCompletedMsg = xi18nc("@info:status",
          "Rollback of <application>Hg</application> repository completed successfully.");
 
-    emit infoMessage(infoMsg);
+    Q_EMIT infoMessage(infoMsg);
     m_hgWrapper->rollback();
     KMessageBox::information(0, m_hgWrapper->readAllStandardOutput());
-    emit itemVersionsChanged();
+    Q_EMIT itemVersionsChanged();
 }
 
 void FileViewHgPlugin::slotOperationCompleted(int exitCode, QProcess::ExitStatus exitStatus)
 {
     if ((exitStatus != QProcess::NormalExit) || (exitCode != 0)) {
-        emit errorMessage(m_errorMsg);
+        Q_EMIT errorMessage(m_errorMsg);
     }
     else {
         m_contextItems.clear();
-        emit operationCompletedMessage(m_operationCompletedMsg);
-        emit itemVersionsChanged();
+        Q_EMIT operationCompletedMessage(m_operationCompletedMsg);
+        Q_EMIT itemVersionsChanged();
     }
 }
 
 void FileViewHgPlugin::slotOperationError()
 {
     m_contextItems.clear();
-    emit errorMessage(m_errorMsg);
+    Q_EMIT errorMessage(m_errorMsg);
 }
 
 void FileViewHgPlugin::clearMessages() const
