@@ -97,7 +97,7 @@ public:
      */
     bool normalExit(const QString &repoLocation);
 
-signals:
+Q_SIGNALS:
     // These signals are emitted for every ServerProcessType in list. Its upto
     // the owner of this wrapper to decide which server was updated. If any of
     // these signals are emitted cleanUnused() is called and every initiater
@@ -109,7 +109,7 @@ signals:
 
 private:
 
-private slots:
+private Q_SLOTS:
     void slotFinished(int exitCode, QProcess::ExitStatus status);
 
 private:
@@ -132,35 +132,35 @@ public:
 
     ServerProcessType() 
     {
-        connect(&process, SIGNAL(readyReadStandardOutput()), 
-                this, SLOT(slotAppendOutput()));
-        connect(&process, SIGNAL(readyReadStandardError()),
-                this, SLOT(slotAppendRemainingOutput()));
+        connect(&process, &QProcess::readyReadStandardOutput,
+                this, &ServerProcessType::slotAppendOutput);
+        connect(&process, &QProcess::readyReadStandardError,
+                this, &ServerProcessType::slotAppendRemainingOutput);
         connect(&process, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished),
                 this, &ServerProcessType::slotFinished);
     }
 
-signals:    
+Q_SIGNALS:    
     void readyReadLine(const QString &repoLocation, const QString &line);
 
-private slots:
+private Q_SLOTS:
     void slotAppendOutput() 
     {
         if (process.canReadLine()) {
-            emit readyReadLine(process.workingDirectory(),
+            Q_EMIT readyReadLine(process.workingDirectory(),
                 QTextCodec::codecForLocale()->toUnicode(process.readAllStandardOutput()).trimmed());
         }
     }
 
     void slotAppendRemainingOutput() 
     {
-            emit readyReadLine(process.workingDirectory(),
+            Q_EMIT readyReadLine(process.workingDirectory(),
                 QTextCodec::codecForLocale()->toUnicode(process.readAllStandardError()).trimmed());
     }
 
     void slotFinished() 
     {
-        emit readyReadLine(process.workingDirectory(),
+        Q_EMIT readyReadLine(process.workingDirectory(),
                                i18n("## Server Stopped! ##\n"));
     }
 };
