@@ -54,13 +54,13 @@ HgStatusList::HgStatusList(QWidget *parent):
 
     connect(m_statusTable, &QTableWidget::currentItemChanged,
             this, &HgStatusList::currentItemChangedSlot);
-    connect(m_statusTable->horizontalHeader(), SIGNAL(sectionClicked(int)),
-            this, SLOT(headerClickedSlot(int)));
+    connect(m_statusTable->horizontalHeader(), &QHeaderView::sectionClicked,
+            this, &HgStatusList::headerClickedSlot);
 }
 
 void HgStatusList::currentItemChangedSlot()
 {
-    emit itemSelectionChanged(
+    Q_EMIT itemSelectionChanged(
         m_statusTable->item(m_statusTable->currentRow(), 1)->text()[0].toLatin1(),
         m_statusTable->item(m_statusTable->currentRow(), 2)->text());
 }
